# Rename Dirs

A python script to rename multiple directories to lowercase words with underscore separators.

## Why?

I like to keep my PC's folder structure neat and uniform but, during intense hackathons, i mess up my project's folder name format. Automating the renaming process made my life a little easier.

## Format

`Example File.txt` -> `example_file.txt`

## Installation

```bash
pip install rename-dirs
```

## Example

* After installing, run `rename-dirs`
* Enter directory path:
<img width="669" alt="dir_path" src="https://media.discordapp.net/attachments/650996852623409152/805400604532408360/unknown.png">

* Enter Y/n for each file/folder:
<img width="718" alt="yes_or_no" src="https://media.discordapp.net/attachments/650996852623409152/805401321288499200/unknown.png">

* Initial folder structure:
<img width="669" alt="inital_structure" src="https://media.discordapp.net/attachments/650996852623409152/805400017359077426/unknown.png">

* Final folder structure:
<img width="669" alt="final_structure" src="https://media.discordapp.net/attachments/650996852623409152/805401340649799691/unknown.png">
